vim.o.showmatch = true

vim.wo.number = true
vim.wo.relativenumber = true

vim.o.mouse = "a"

vim.o.ignorecase = true
vim.o.smartcase = true
vim.o.expandtab = true
vim.o.shiftwidth = 4
vim.o.tabstop = 4
vim.o.cursorline = true

-- Enable auto-indentation
vim.o.autoindent = true

-- Highlight search results
vim.o.hlsearch = true

-- Highlight current line
vim.o.cursorline = true
vim.o.cursorlineopt = "number"

-- Increase speed for terminals
vim.o.ttyfast = true

vim.diagnostic.config({ virtual_text = false })
vim.g.nvim_tree_respect_buf_cwd = 1
vim.g.NERDCompactSexyComs = 1
--Set completeopt to have a better completion experience
-- :help completeopt
-- menuone: popup even when there's only one match
-- noinsert: Do not insert text until a selection is made
-- noselect: Do not select, force to select one from the menu
-- shortness: avoid showing extra messages when using completion
-- updatetime: set updatetime for CursorHold
vim.opt.completeopt = { "menuone", "noselect", "noinsert" }
vim.opt.shortmess = vim.opt.shortmess + { c = true }
vim.g.updatetime = 300

vim.api.nvim_create_autocmd("TextYankPost", {
	callback = function()
		vim.highlight.on_yank()
	end,
})

vim.o.signcolumn = "yes"

vim.g.mapleader = " "

vim.o.clipboard = "unnamedplus"

vim.filetype.add({
	pattern = {
		[".*/hypr/.*%.conf"] = "hyprlang",
		[".*%.typ"] = "typst",
	},
})

vim.o.undofile = true

require("plugins")

vim.cmd([[
  highlight Normal guibg=none ctermbg=none
  highlight NonText guibg=none ctermbg=none
  highlight LineNr guifg=#606060
  highlight SignColumn guibg=none ctermbg=none
  highlight LspInlayHint guibg=none ctermbg=none
]])

require("notify").setup({
	background_colour = "#000000",
})
